@@ -839,7 +839,7 @@ static inline void AtomicDivide(word &Q0, word &Q1, const word *A, word B0, word
 		Q1 = SubatomicDivide(T+1, B0, B1);
 		Q0 = SubatomicDivide(T, B0, B1);
 
-#ifndef NDEBUG
+#ifdef DEBUG
 		// multiply quotient and divisor and add remainder, make sure it equals dividend
 		assert(!T[2] && !T[3] && (T[1] < B1 || (T[1]==B1 && T[0]<B0)));
 		word P[4];
@@ -1091,7 +1091,7 @@ inline unsigned int RoundupSize(unsigned int n)
 Integer::Integer()
 	: reg(2), sign(POSITIVE)
 {
-	reg[0] = reg[1] = 0;
+	reg[(unsigned int)0] = reg[(unsigned int)1] = 0;
 }
 
 Integer::Integer(const Integer& t)
@@ -1110,17 +1110,17 @@ Integer::Integer(long value)
 		sign = NEGATIVE;
 		value = -value;
 	}
-	reg[0] = word(value);
+	reg[(unsigned int)0] = word(value);
 #ifdef __GNUC__
-	reg[1] = 0;
+	reg[(unsigned int)1] = 0;
 #else
-	reg[1] = sizeof(value)>WORD_SIZE ? word(value>>WORD_BITS) : 0;
+	reg[(unsigned int)1] = sizeof(value)>WORD_SIZE ? word(value>>WORD_BITS) : 0;
 #endif
 }
 
 long Integer::ConvertToLong() const
 {
-	unsigned long value = reg[0];
+	unsigned long value = reg[(unsigned int)0];
 #ifndef __GNUC__
 	value += sizeof(value)>WORD_SIZE ? ((unsigned long)reg[1]<<WORD_BITS) : 0;
 #endif
@@ -1174,7 +1174,7 @@ const Integer &Integer::One()
 
 bool Integer::operator!() const
 {
-	return IsNegative() ? false : (reg[0]==0 && WordCount()==0);
+	return IsNegative() ? false : (reg[(unsigned int)0]==0 && WordCount()==0);
 }
 
 Integer& Integer::operator=(const Integer& t)
@@ -1248,8 +1248,8 @@ void swap(Integer &a, Integer &b)
 Integer::Integer(word value, unsigned int length)
 	: reg(RoundupSize(length)), sign(POSITIVE)
 {
-	reg[0] = value;
-	SetWords(reg+1, 0, reg.size-1);
+	reg[(unsigned int)0] = value;
+	SetWords(reg+(unsigned int)1, 0, reg.size-(unsigned int)1);
 }
 
 
@@ -1444,7 +1444,7 @@ void Integer::Randomize(RandomNumberGenerator &rng, unsigned int nbits)
 	const unsigned int nbytes = nbits/8 + 1;
 	SecByteBlock buf(nbytes);
 	rng.GetBlock(buf, nbytes);
-	buf[0] = (byte)Crop(buf[0], nbits % 8);
+	buf[(unsigned int)0] = (byte)Crop(buf[(unsigned int)0], nbits % 8);
 	Decode(buf, nbytes, UNSIGNED);
 }
 
@@ -1476,7 +1476,7 @@ void Integer::Randomize(RandomNumberGenerator &rng, const Integer &min, const In
 				return;
 
 			case ODD:
-				reg[0] |= 1;
+				reg[(unsigned int)0] |= 1;
 				if (*this <= max)
 					return;
 				else
@@ -1921,7 +1921,7 @@ word Integer::ShortDivide(Integer &quotient, const Integer &dividend, word divis
 	if ((divisor & (divisor-1)) == 0)   // divisor is a power of 2
 	{
 		quotient = dividend >> (BitPrecision(divisor)-1);
-		return dividend.reg[0] & (divisor-1);
+		return dividend.reg[(unsigned int)0] & (divisor-1);
 	}
 
 	unsigned int i = dividend.WordCount();
@@ -1967,7 +1967,7 @@ word operator%(const Integer &dividend, word divisor)
 	word remainder;
 
 	if ((divisor & (divisor-1)) == 0)   // divisor is a power of 2
-		remainder = dividend.reg[0] & (divisor-1);
+		remainder = dividend.reg[(unsigned int)0] & (divisor-1);
 	else
 	{
 		unsigned int i = dividend.WordCount();
@@ -2050,7 +2050,7 @@ bool Integer::IsSquare() const
 
 bool Integer::IsUnit() const
 {
-	return (WordCount() == 1) && (reg[0] == 1);
+	return (WordCount() == 1) && (reg[(unsigned int)0] == 1);
 }
 
 Integer Integer::MultiplicativeInverse() const
