@@ -56,10 +56,10 @@
 #	define DEBUG_STR _T("")
 #endif
 
-#define TSS_PRODUCT_NAME _T("Tripwire(R) 2.3.1.") 
+#define TSS_PRODUCT_NAME _T("Open Soure Tripwire(R) 2.4.1.") 
 
 #define TSS_COPYRIGHT_NOTICE \
-_T("Tripwire 2.3 Portions copyright 2000 Tripwire, Inc. Tripwire is a registered\n\
+_T("Open Source Tripwire 2.4 Portions copyright 2000 Tripwire, Inc. Tripwire is a registered\n\
 trademark of Tripwire, Inc. This software comes with ABSOLUTELY NO WARRANTY;\n\
 for details use --version. This is free software which may be redistributed\n\
 or modified only under certain conditions; see COPYING for details.\n\
@@ -115,7 +115,7 @@ TSS_BeginStringtable( cTW )
 	TSS_StringEntry( tw::STR_DEF_CFG_FILENAME,		_T("/etc/tw.cfg")),
 #endif
 
-	TSS_StringEntry( tw::STR_WIN_NT_ONLY,			_T("Tripwire(R) runs only on Windows NT.")),
+	TSS_StringEntry( tw::STR_WIN_NT_ONLY,			_T("Open Source Tripwire(R) runs only on Windows NT.")),
 	TSS_StringEntry( tw::STR_GET_HELP,				_T("Use --help to get help.")),
 	TSS_StringEntry( tw::STR_NEWLINE,				_T("\n")),
 	TSS_StringEntry( tw::STR_ERR_TWCFG_CANT_READ,   _T("Configuration file could not be read.")),
@@ -158,7 +158,7 @@ TSS_BeginStringtable( cTW )
 	TSS_StringEntry( tw::STR_WRITE_REPORT_FILE,		_T("Wrote report file: ") ),
 	TSS_StringEntry( tw::STR_WRITE_CONFIG_FILE,		_T("Wrote configuration file: ") ),
 
-    TSS_StringEntry( tw::STR_REPORT_TITLE,            _T("Tripwire(R) 2.3.0 Integrity Check Report") ),    
+    TSS_StringEntry( tw::STR_REPORT_TITLE,            _T("Open Source Tripwire(R) 2.4.1 Integrity Check Report") ),    
     TSS_StringEntry( tw::STR_R_GENERATED_BY,          _T("Report generated by: ") ),
     TSS_StringEntry( tw::STR_R_CREATED_ON,            _T("Report created on: ") ),
 	TSS_StringEntry( tw::STR_DB_CREATED_ON,			  _T("Database generated on: ") ),
@@ -219,7 +219,7 @@ TSS_BeginStringtable( cTW )
     TSS_StringEntry( tw::STR_REMOVED_SHORT,           _T("R") ),
     TSS_StringEntry( tw::STR_CHANGED_SHORT,           _T("C") ),
         
-	TSS_StringEntry( tw::STR_DBPRINT_TITLE,			  _T("Tripwire(R) 2.3.0 Database") ),
+	TSS_StringEntry( tw::STR_DBPRINT_TITLE,			  _T("Open Source Tripwire(R) 2.4.1 Database") ),
 	TSS_StringEntry( tw::STR_DB_GENERATED_BY,		  _T("Database generated by: ") ),
     TSS_StringEntry( tw::STR_TOTAL_NUM_FILES,         _T("Total number of objects: ") ),
     TSS_StringEntry( tw::STR_END_OF_DB,               _T("*** End of database ***") ),
